import { queryStr } from '@/utils/query';
import { request } from 'umi';
import { api } from '../api'
export interface AddTag {
  id?: string,
  tagName: string,
  type: string
}
export interface MediaList {
  describeInfo?: string,
  groupId?: string,
  id?: string,
  mediaAuthor?: string,
  mediaContent?: string,
  mediaContentSourceUrl?: string,
  mediaDigest?: string,
  mediaTagIds?: string | string[],
  mediaThumbMediaId?: string,
  mediaType?: string,
  title?: string,
  url?: string
}
export interface GetMediaList {
  mediaTagId?: string,
  pageNum: string,
  pageSize: string,
  mediaType: string,
  tagIds?: string | string[],
  groupId?: string,
}

export interface CreateGraphic {
  groupId: number,
  mediaTagIds: number[],
  sysMediaGraphics: {
    author: string,
    content: string,
    contentSourceUrl?: string,
    digest?: string,
    needOpenComment?: boolean,
    onlyFansCanComment?: boolean,
    showCoverPic?: boolean,
    title: string,
    url: string
  }[]
}
export interface EditGraphic extends CreateGraphic {
  id: string,
  appId: string
}
export interface GetGraphicList {
  mediaType?: string,
  groupId?: string,
  pageNum: number,
  pageSize: number,
  tagIds?: number[]
}
// export interface GetWeChatData {
//   appId: string,
//   count: string | number,
//   offset: string
// }
export interface GetWeChatData {
  mpId: number,
  mediaType: string,
  pageNum: number,
  pageSize: number
}
export interface GetWeChatITData {
  appId: string,
  count: string | number,
  offset: string,
  type: string
}
// export async function getGzhData() {
//   return request('/api/data/gzhsc');
// }
/**获取上传接口 */
export async function getFileUrl(params: { type: string }) {
  return request(`${api}/adq/oss/ossUpload?type=${params.type}`);
}
/*************************标签**********************************/
/**新增标签 */
export async function addTag(params?: AddTag) {
  return request(api + '/adq/mediaTag/create', {
    method: 'POST',
    data: params,
  });
}
/**编辑标签 */
export async function editTag(params?: AddTag) {
  return request(api + '/adq/mediaTag/edit', {
    method: 'POST',
    data: params,
  });
}

/**删除标签 */
export async function delTag(params: { id: string }) {
  return request(`${api}/adq/mediaTag/${params.id}`, {
    method: 'DELETE',
  });
}
/**获取标签列表*/
export async function getTagList(params: { type: string }) {
  return request(`${api}/adq/mediaTag/list?type=${params.type}`);
}
/*************************分类**********************************/
/**新增标签 */
export async function addClass(params?: { groupName: string }) {
  return request(api + '/adq/sysMediaGroup/create', {
    method: 'POST',
    data: params,
  });
}
/**编辑标签 */
export async function editClass(params?: { groupName: string, id: string }) {
  return request(api + '/adq/sysMediaGroup/edit', {
    method: 'POST',
    data: params,
  });
}

/**删除标签 */
export async function delClass(params: { id: string }) {
  return request(`${api}/adq/sysMediaGroup/${params.id}`, {
    method: 'DELETE',
  });
}
/**获取标签列表*/
export async function getClass(params: any) {
  return request(`${api}/adq/sysMediaGroup?type=${params?.type}`);
}
/*************************素材**********************************/
/** 新增非图文本地素材*/
export async function addMediaList(params?: MediaList) {
  return request(api + '/adq/sysMedia/create', {
    method: 'POST',
    data: params,
  });
}
/** 编辑非图文本地素材*/
export async function editMediaList(params?: MediaList) {
  return request(api + '/adq/sysMedia/edit', {
    method: 'POST',
    data: params,
  });
}
/** 新增图文本地素材*/
export async function createGraphic(params: CreateGraphic) {
  return request(api + '/adq/sysMedia/createGraphic', {
    method: 'POST',
    data: params,
  });
}
/** 新增图文微信素材*/
export async function createGraphicMaterial(params: CreateGraphic) {
  return request(api + '/adq/sysMedia/addWxGraphicMaterial', {
    method: 'POST',
    data: params,
  });
}
/** 编辑图文本地素材*/
export async function editGraphic(params: EditGraphic) {
  return request(api + '/adq/sysMedia/editGraphic', {
    method: 'POST',
    data: params,
  });
}
/** 编辑图文微信素材*/
export async function editGraphicWxMaterial(params: EditGraphic) {
  return request(api + '/adq/sysMedia/updateWxMaterial', {
    method: 'POST',
    data: params,
  });
}
/** 获取本地素材*/
export async function getMediaList(params: GetMediaList) {
  return request(`${api}/adq/sysMedia/list${queryStr(params)}`);
}
/** 删除本地素材*/
export async function delMediaList(params: { id: string }) {
  return request(`${api}/adq/sysMedia/${params.id}`, {
    method: 'DELETE',
  });
}
/**同步本地图文素材 */
export async function syncPermanentGraphicMedias(params: { appId: string[], mediaId: string }) {
  return request(api + '/adq/sysMedia/syncPermanentGraphicMaterial', {
    method: 'POST',
    data: params,
  });
}
/**同步本地非图文素材 */
export async function syncMedias(params: { appId: string[], mediaId: string }) {
  return request(api + '/adq/sysMedia/syncPermanent', {
    method: 'POST',
    data: params,
  });
}
/**获取微信图文素材 */
export async function getWeChatITData(params: GetWeChatITData) {
  return request(`${api}/adq/sysMedia/batchGetMaterialNews${queryStr(params)}`);
}


// /**获取微信非图文素材 */
// export async function getWeChatData(params: GetWeChatData) {
//   return request(`${api}/adq/sysMedia/batchGetMateria${queryStr(params)}`);
// }
/**获取微信非图文素材 */
export async function getWeChatData(params: GetWeChatData) {
  let { mpId, ...param } = params
  return request(`${api}/adq/mp/media/list/${mpId}`, {
    method: 'POST',
    data: param,
  });
}
/**更新公众号下素材*/
export async function updateMediaCache(params: { mpId: number, mediaType: string }) {
  let { mpId, mediaType } = params
  return request(`${api}/adq/mp/media/syncMedia/${mpId}/${mediaType}`, {
    method: 'PUT'
  })
}
/** 删除微信素材*/
export async function delMediawx(id: number) {
  return request(`${api}/adq/mp/media/${id}`, {
    method: 'DELETE',
  });
}
/**微信素材详情*/
export async function getWxMediaInfo(params: { id: number, isCon?: boolean }) {
  let { id, isCon = true } = params
  return request(`${api}/adq/mp/media/${id}/${isCon}`);
}

/**导入文章 */
export async function exportMediaByUrl(params: { url: string }) {
  return request(`${api}/adq/sysMedia/exportMediaByUrl${queryStr(params)}`);
}
export async function exportMediaByUrl1(url: string) {
  return fetch(`${api}/adq/mp/media/parseWxNewsByUrl?url=${url}`, {
    headers: { ['Authorization']: 'Bearer ' + sessionStorage.getItem('Admin-Token') },
  });
}




/**本地素材详情*/
export async function getGraphicDetail(params: { id: string }) {
  return request(`${api}/adq/sysMedia/graphicDetail/${params.id}`);
}
/**查询图文同步结果 */
export async function syncResult(params: any) {
  return request(api + '/adq/sysMedia/syncResult', {
    method: 'POST',
    data: params,
  });
}
/**批量上传非图文素材 */
export async function bantchAdd(params: any) {
  return request(`${api}/adq/sysMedia/bantchAdd`, {
    method: 'PUT',
    data: params
  })
}
/**oss删除 */
export async function delOss(params: any) {
  return request(`${api}/adq/oss/${params}`, {
    method: 'DELETE',
    // data: params
  });
}



//=========================新接口===================
// belongUser 0 公共 1 个人
/**获取本地素材图片列表 */
export async function bdSysMediaListImg(params: { parentId?: any, belongUser: boolean, pageNum: number, pageSize: number }) {
  const { belongUser, ...param } = params
  return request(api + `/adq/sysMediaImage/list/${belongUser}`, {
    method: 'POST',
    data: param,
  });
}
/**获取本地素材视频列表 */
export async function bdSysMediaListVideo(params: { parentId?: any, belongUser: boolean, pageNum: number, pageSize: number }) {
  const { belongUser, ...param } = params
  return request(api + `/adq/sysMediaVideo/list/${belongUser}`, {
    method: 'POST',
    data: param,
  });
}
/**修改本地素材 */
export async function bdSysMediaEdit(params: { belongUser: boolean, sysMediaId: number, mediaType: "IMG" | "VIDEO" }) {
  const { belongUser, sysMediaId, ...param } = params
  return request(api + `/adq/sysMedia/${belongUser}/${sysMediaId}`, {
    method: 'PUT',
    data: param
  });
}
/**新增本地素材 */
export async function bdSysMediaAdd(params: { belongUser: boolean, parentId: number, mediaType: "IMG" | "VIDEO" }) {
  const { belongUser, mediaType, ...param } = params
  if (mediaType === 'IMG') {
    return request(api + `/adq/sysMediaImage/${belongUser}`, {
      method: 'POST',
      data: param,
    });
  } else {
    return request(api + `/adq/sysMediaVideo/${belongUser}`, {
      method: 'POST',
      data: param,
    });
  }
  
}
/**新增微信素材*/
export async function wxSysMediaAdd(params: { mediaType: "image" | "news" | "voice" | "video", localMediaId: number, mpId: number, news: any }) {
  return request(api + `/adq/mp/media`, {
    method: 'POST',
    data: params,
  });
}
/**删除本地素材 */
export async function delMedia(sysMediaId: any) {
  return request(`${api}/adq/sysMedia/${sysMediaId}`, {
    method: 'DELETE',
  });
}
/**获取本地素材详情*/
export async function getMedia(sysMediaId: any) {
  return request(`${api}/adq/sysMedia/${sysMediaId}`, {
    method: 'GET',
  });
}
/**同步素材 */
export async function syncMedia(params: { sysMediaId: number, mpIds: number }) {
  const { mpIds, sysMediaId } = params
  return request(api + `/adq/sysMedia/syncToMp/${sysMediaId}/${mpIds}`, {
    method: 'PUT',
  });
}
/**返回微信媒体ID的同步接口 */
export async function syncForSend(params: { sysMediaId: number, mpIds: number }) {
  const { mpIds, sysMediaId } = params
  return request(api + `/adq/sysMedia/syncForSend/${sysMediaId}/${mpIds}`, {
    method: 'PUT',
  });
}

/**获取素材管理的公众号*/
export async function getWxlist(sysMediaId: number) {
  return request(api + `/adq/sysMedia/getBindMps/${sysMediaId}`, {
    method: 'GET'
  })
}
/**编辑素材关联的公众号 */
export async function editWxlist(params: { sysMediaId: number, mpIds: any }) {
  const { sysMediaId, mpIds } = params
  return request(api + `/adq/sysMedia/bindMediaMps/${sysMediaId}`, {
    method: 'POST',
    data: mpIds
  })
}
/**获取图片素材文件夹目录树*/
export async function getFolderTreeImg(props: { belongUser: any }) {
  let { belongUser } = props
  return request(api + `/adq/sysMediaImage/folderTree/${belongUser}`, {
    method: 'GET'
  })
}
/**获取视频素材文件夹目录树*/
export async function getFolderTreeVideo(props: { belongUser: any }) {
  let { belongUser } = props
  return request(api + `/adq/sysMediaVideo/folderTree/${belongUser}`, {
    method: 'GET'
  })
}
/*改变文件位置*/
export async function editMediaFolder(params: { sysMediaId: number, folderId: number }) {
  const { folderId, sysMediaId } = params
  return request(api + `/adq/sysMedia/configMediaFolder/${folderId}/${sysMediaId}`, {
    method: 'PUT',
  });
}
/** 排序 */
export async function configSortApi({ sysMediaId, sort }: { sysMediaId: number, sort: number }) {
  return request(api + `/adq/sysMedia/configMediaSort/${sysMediaId}/${sort}`, {
    method: 'PUT'
  });
}